<?php
/**
 * Plugin Name: Custom Social Media Icons
 * Plugin URL: https://wordpress.org/plugins/custom-social-media-icons
 * Description: Custom Social Media Icons plugin is a dynamic, simple solution to show icons that connect visitors to your numerous social pages.
 * Version: 1.0
 * Author: EvinceDev
 * Text Domain: custom-social-media-icons
 * License: GNU General Public License v3.0 (or later)
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Author URI: https://evincedev.com/
 */
add_action('plugins_loaded', 'csi_custom_social_icons_load_textdomain');

#Load textdomain

function csi_custom_social_icons_load_textdomain() {
    load_plugin_textdomain('custom-social-media-icons', false, plugin_basename(dirname(__FILE__)) . '/languages');
}

class CSI_Custom_Social_Icons_Widget extends WP_Widget {

    /**
     * Plugin version for enqueued static resources.
     * @var string
     */
    protected $version = '1.0';

    /**
     * Default widget values.
     * @var array
     */
    protected $defaults;

    /**
     * Default widget values.
     * @var array
     */
    protected $sizes;

    /**
     * Default widget profile values.
     * @var array
     */
    protected $profiles;

    /**
     * Array of widget instance IDs. Used to generate CSS.
     * @var array
     */
    protected $active_instances;

    /**
     * Controls custom css output.
     * @var bool
     */
    protected $disable_css_output;

    /**
     * Constructor method.
     * Set some global values and create widget.
     */
    function __construct() {

        /**
         * Filter for default widget option values.
         * @since 1.0
         * @param array $defaults Default widget options.
         */
        $this->defaults = apply_filters('csi_custom_social_default_styles', array(
            'title' => '',
            'new_window' => 0,
            'size' => 30,
            'border_radius' => 2,
            'border_width' => 0,
            'border_color' => '#ffffff',
            'border_color_hover' => '#ffffff',
            'icon_color' => '#ffffff',
            'icon_color_hover' => '#ffffff',
            'background_color' => '#999999',
            'background_color_hover' => '#666666',
            'alignment' => 'alignleft',
            'behance' => '',
            'bloglovin' => '',
            'dribbble' => '',
            'email' => '',
            'facebook' => '',
            'flickr' => '',
            'github' => '',
            'gplus' => '',
            'instagram' => '',
            'linkedin' => '',
            'medium' => '',
            'periscope' => '',
            'phone' => '',
            'pinterest' => '',
            'rss' => '',
            'snapchat' => '',
            'stumbleupon' => '',
            'tumblr' => '',
            'twitter' => '',
            'vimeo' => '',
            'xing' => '',
            'youtube' => '',
        ));

        /**
         * Filter for social profile choices.
         * @since 1.0
         * @param array $profiles Social icons to include in widget options.
         */
        $this->profiles = apply_filters('csi_custom_social_default_profiles', array(
            'behance' => array(
                'label' => __('Behance URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('behance', __('Behance', 'custom-social-media-icons')),
            ),
            'bloglovin' => array(
                'label' => __('Bloglovin URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('bloglovin', __('Bloglovin', 'custom-social-media-icons')),
            ),
            'dribbble' => array(
                'label' => __('Dribbble URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('dribbble', __('Dribbble', 'custom-social-media-icons')),
            ),
            'email' => array(
                'label' => __('Email URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('email', __('Email', 'custom-social-media-icons')),
            ),
            'facebook' => array(
                'label' => __('Facebook URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('facebook', __('Facebook', 'custom-social-media-icons')),
            ),
            'flickr' => array(
                'label' => __('Flickr URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('flickr', __('Flickr', 'custom-social-media-icons')),
            ),
            'github' => array(
                'label' => __('GitHub URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('github', __('GitHub', 'custom-social-media-icons')),
            ),
            'gplus' => array(
                'label' => __('Google+ URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('gplus', __('Google+', 'custom-social-media-icons')),
            ),
            'instagram' => array(
                'label' => __('Instagram URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('instagram', __('Instagram', 'custom-social-media-icons')),
            ),
            'linkedin' => array(
                'label' => __('Linkedin URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('linkedin', __('LinkedIn', 'custom-social-media-icons')),
            ),
            'medium' => array(
                'label' => __('Medium URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('medium', __('Medium', 'custom-social-media-icons')),
            ),
            'periscope' => array(
                'label' => __('Periscope URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('periscope', __('Periscope', 'custom-social-media-icons')),
            ),
            'phone' => array(
                'label' => __('Phone URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('phone', __('Phone', 'custom-social-media-icons')),
            ),
            'pinterest' => array(
                'label' => __('Pinterest URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('pinterest', __('Pinterest', 'custom-social-media-icons')),
            ),
            'rss' => array(
                'label' => __('RSS URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('rss', __('RSS', 'custom-social-media-icons')),
            ),
            'snapchat' => array(
                'label' => __('Snapchat URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('snapchat', __('Snapchat', 'custom-social-media-icons')),
            ),
            'stumbleupon' => array(
                'label' => __('StumbleUpon URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('stumbleupon', __('StumbleUpon', 'custom-social-media-icons')),
            ),
            'tumblr' => array(
                'label' => __('Tumblr URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('tumblr', __('Tumblr', 'custom-social-media-icons')),
            ),
            'twitter' => array(
                'label' => __('Twitter URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('twitter', __('Twitter', 'custom-social-media-icons')),
            ),
            'vimeo' => array(
                'label' => __('Vimeo URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('vimeo', __('Vimeo', 'custom-social-media-icons')),
            ),
            'xing' => array(
                'label' => __('Xing URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('xing', __('xing', 'custom-social-media-icons')),
            ),
            'youtube' => array(
                'label' => __('YouTube URI', 'custom-social-media-icons'),
                'pattern' => $this->csi_get_icon_markup('youtube', __('YouTube', 'custom-social-media-icons')),
            ),
        ));

        /**
         * Filter to disable output of custom CSS.
         *
         * Setting this to true in your child theme will:
         *  - Stop output of inline custom icon CSS.
         *  - Stop styling options showing in Custom Social Media Icons widget settings.
         *
         * The intent if enabling is that your theme will provide CSS for all
         * widget areas, instead of allowing people to set their own icon
         * styles. You should consider mentioning in theme documentation that
         * Custom Social Media Icons widget settings will not display styling
         * options, as your theme styles icons instead.
         *
         * @since 1.0.
         *
         * @param bool $disable_css_output True if custom CSS should be disabled.
         */
        $this->disable_css_output = apply_filters('csi_custom_social_disable_custom_css', false);

        $widget_ops = array(
            'classname' => 'custom-social-media-icons',
            'description' => __('Displays select social icons.', 'custom-social-media-icons'),
        );

        $control_ops = array(
            'id_base' => 'custom-social-media-icons',
        );

        $this->active_instances = array();

        parent::__construct('custom-social-media-icons', __('Custom Social Media Icons', 'custom-social-media-icons'), $widget_ops, $control_ops);

        #Enqueue scripts and styles
        add_action('wp_enqueue_scripts', array($this, 'csi_enqueue_css'));

        #Load CSS in footer
        add_action('wp_footer', array($this, 'csi_css'));

        #Load color picker
        add_action('admin_enqueue_scripts', array($this, 'csi_load_color_picker'));
        add_action('admin_footer-widgets.php', array($this, 'csi_print_scripts'), 9999);
    }

    /**
     * Color Picker.
     * Enqueue the color picker script.
     */
    function csi_load_color_picker($hook) {
        if ('widgets.php' != $hook)
            return;
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_script('wp-color-picker');
        wp_enqueue_script('underscore');
    }

    /**
     * Print scripts.
     * Reference https://core.trac.wordpress.org/attachment/ticket/25809/color-picker-widget.php
     */
    function csi_print_scripts() {
        ?>
        <script>
            (function ($) {
                function csi_initColorPicker(widget) {
                    widget.find('.csi-color-picker').wpColorPicker({
                        change: function (event) {
                            var $picker = $(this);
                            _.throttle(setTimeout(function () {
                                $picker.trigger('change');
                            }, 5), 250);
                        },
                        width: 235,
                    });
                }

                function csi_onFormUpdate(event, widget) {
                    csi_initColorPicker(widget);
                }

                $(document).on('widget-added widget-updated', csi_onFormUpdate);

                $(document).ready(function () {
                    $('#widgets-right .widget:has(.csi-color-picker)').each(function () {
                        csi_initColorPicker($(this));
                    });
                });
            }(jQuery));
        </script>
        <?php
    }

    /**
     * Widget Form.
     * Outputs the widget form that allows users to control the output of the widget.
     */
    function form($instance) {

        #Merge with defaults
        $instance = wp_parse_args((array) $instance, $this->defaults);
        ?>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
                <?php _e('Title:', 'custom-social-media-icons'); ?>
            </label> 
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($instance['title']); ?>" />
        </p>

        <p>
            <label>
                <input id="<?php echo esc_attr($this->get_field_id('new_window')); ?>" type="checkbox" name="<?php echo esc_attr($this->get_field_name('new_window')); ?>" value="1" <?php checked(1, $instance['new_window']); ?>/> <?php esc_html_e('Open links in new window?', 'custom-social-media-icons'); ?>
            </label>
        </p>

        <?php if (!$this->disable_css_output) { ?>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('size')); ?>">
                    <?php _e('Icon Size', 'custom-social-media-icons'); ?>:
                </label> 
                <input id="<?php echo esc_attr($this->get_field_id('size')); ?>" name="<?php echo esc_attr($this->get_field_name('size')); ?>" type="text" value="<?php echo esc_attr($instance['size']); ?>" size="3" />px
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('border_radius')); ?>"><?php _e('Icon Border Radius:', 'custom-social-media-icons'); ?></label>
                <input id="<?php echo esc_attr($this->get_field_id('border_radius')); ?>" name="<?php echo esc_attr($this->get_field_name('border_radius')); ?>" type="text" value="<?php echo esc_attr($instance['border_radius']); ?>" size="3" />px
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('border_width')); ?>"><?php _e('Border Width:', 'custom-social-media-icons'); ?></label>
                <input id="<?php echo esc_attr($this->get_field_id('border_width')); ?>" name="<?php echo esc_attr($this->get_field_name('border_width')); ?>" type="text" value="<?php echo esc_attr($instance['border_width']); ?>" size="3" />px
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('alignment')); ?>"><?php _e('Alignment', 'custom-social-media-icons'); ?>:</label>
                <select id="<?php echo esc_attr($this->get_field_id('alignment')); ?>" name="<?php echo $this->get_field_name('alignment'); ?>">
                    <option value="alignleft" <?php selected('alignright', esc_attr($instance['alignment'])) ?>><?php _e('Align Left', 'custom-social-media-icons'); ?></option>
                    <option value="aligncenter" <?php selected('aligncenter', esc_attr($instance['alignment'])) ?>><?php _e('Align Center', 'custom-social-media-icons'); ?></option>
                    <option value="alignright" <?php selected('alignright', esc_attr($instance['alignment'])) ?>><?php _e('Align Right', 'custom-social-media-icons'); ?></option>
                </select>
            </p>

            <hr style="background: #ccc; border: 0; height: 1px; margin: 20px 0;" />

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('background_color')); ?>"><?php _e('Icon Color:', 'custom-social-media-icons'); ?></label><br /> 
                <input id="<?php echo esc_attr($this->get_field_id('icon_color')); ?>" name="<?php echo esc_attr($this->get_field_name('icon_color')); ?>" type="text" class="csi-color-picker" data-default-color="<?php echo esc_attr($this->defaults['icon_color']); ?>" value="<?php echo esc_attr($instance['icon_color']); ?>" size="6" />
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('background_color_hover')); ?>"><?php _e('Icon Hover Color:', 'custom-social-media-icons'); ?></label><br />
                <input id="<?php echo esc_attr($this->get_field_id('icon_color_hover')); ?>" name="<?php echo esc_attr($this->get_field_name('icon_color_hover')); ?>" type="text" class="csi-color-picker" data-default-color="<?php echo esc_attr($this->defaults['icon_color_hover']); ?>" value="<?php echo esc_attr($instance['icon_color_hover']); ?>" size="6" />
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('background_color')); ?>"><?php _e('Background Color:', 'custom-social-media-icons'); ?></label><br /> 
                <input id="<?php echo esc_attr($this->get_field_id('background_color')); ?>" name="<?php echo esc_attr($this->get_field_name('background_color')); ?>" type="text" class="csi-color-picker" data-default-color="<?php echo esc_attr($this->defaults['background_color']); ?>" value="<?php echo esc_attr($instance['background_color']); ?>" size="6" />
            </p>

            <p><label for="<?php echo esc_attr($this->get_field_id('background_color_hover')); ?>"><?php _e('Background Hover Color:', 'custom-social-media-icons'); ?></label><br /> <input id="<?php echo esc_attr($this->get_field_id('background_color_hover')); ?>" name="<?php echo esc_attr($this->get_field_name('background_color_hover')); ?>" type="text" class="csi-color-picker" data-default-color="<?php echo esc_attr($this->defaults['background_color_hover']); ?>" value="<?php echo esc_attr($instance['background_color_hover']); ?>" size="6" /></p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('border_color')); ?>"><?php _e('Border Color:', 'custom-social-media-icons'); ?></label><br /> 
                <input id="<?php echo esc_attr($this->get_field_id('border_color')); ?>" name="<?php echo esc_attr($this->get_field_name('border_color')); ?>" type="text" class="csi-color-picker" data-default-color="<?php echo esc_attr($this->defaults['border_color']); ?>" value="<?php echo esc_attr($instance['border_color']); ?>" size="6" />
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('border_color_hover')); ?>"><?php _e('Border Hover Color:', 'custom-social-media-icons'); ?></label><br /> 
                <input id="<?php echo esc_attr($this->get_field_id('border_color_hover')); ?>" name="<?php echo esc_attr($this->get_field_name('border_color_hover')); ?>" type="text" class="csi-color-picker" data-default-color="<?php echo esc_attr($this->defaults['border_color_hover']); ?>" value="<?php echo esc_attr($instance['border_color_hover']); ?>" size="6" />
            </p>

            <hr style="background: #ccc; border: 0; height: 1px; margin: 20px 0;" />
        <?php } ?>

        <?php
        foreach ((array) $this->profiles as $profile => $data) {
            printf('<p><label for="%s">%s:</label></p>', esc_attr($this->get_field_id($profile)), esc_attr($data['label']));
            printf('<p><input type="text" id="%s" name="%s" value="%s" class="widefat" />', esc_attr($this->get_field_id($profile)), esc_attr($this->get_field_name($profile)), $instance[$profile]);
            printf('</p>');
        }
    }

    /**
     * Form validation and sanitization.
     * Runs when you save the widget form. Allows you to validate or sanitize widget options before they are saved.
     */
    function update($newinstance, $oldinstance) {

        #Fields that can be transparent if their values are unset.
        $can_be_transparent = array(
            'background_color',
            'background_color_hover',
            'border_color',
            'border_color_hover',
        );

        foreach ($newinstance as $key => $value) {

            #Border radius and Icon size must not be empty, must be a digit
            if (( 'border_radius' == $key || 'size' == $key ) && ( '' == $value || !ctype_digit($value) )) {
                $newinstance[$key] = 0;
            }

            if (( 'border_width' == $key || 'size' == $key ) && ( '' == $value || !ctype_digit($value) )) {
                $newinstance[$key] = 0;
            }

            #Accept empty colors for permitted keys.
            elseif (in_array($key, $can_be_transparent, true) && '' == trim($value)) {
                $newinstance[$key] = '';
            }

            #Validate hex code colors 
            elseif (strpos($key, '_color') && 0 == preg_match('/^#(([a-fA-F0-9]{3}$)|([a-fA-F0-9]{6}$))/', $value)) {
                $newinstance[$key] = esc_attr($oldinstance[$key]);
            }

            #Sanitize Profile URIs 
            elseif (array_key_exists($key, (array) $this->profiles) && !is_email($value) && !'phone' === $key) {
                $newinstance[$key] = esc_url($newinstance[$key]);
            }
        }

        return $newinstance;
    }

    /**
     * Widget Output.
     * Outputs the actual widget on the front-end based on the widget options the user selected.
     */
    function widget($args, $instance) {

        extract($args);

        #Merge with defaults
        $instance = wp_parse_args((array) $instance, $this->defaults);

        echo $before_widget;

        if (!empty($instance['title']))
            echo $before_title . apply_filters('widget_title', esc_attr($instance['title']), $instance, $this->id_base) . $after_title;

        $output = '';

        $profiles = (array) $this->profiles;

        foreach ($profiles as $profile => $data) {

            if (empty($instance[$profile]))
                continue;

            $new_window = $instance['new_window'] ? 'target="_blank" rel="noopener noreferrer"' : '';

            if (is_email($instance[$profile]) || false !== strpos($instance[$profile], 'mailto:'))
                $new_window = '';

            if (is_email($instance[$profile])) {
                $output .= sprintf($data['pattern'], 'mailto:' . esc_attr(antispambot($instance[$profile])), $new_window);
            } elseif ('phone' === $profile) {
                $output .= sprintf($data['pattern'], 'tel:' . esc_attr(antispambot($instance[$profile])), $new_window);
            } else {
                $output .= sprintf($data['pattern'], esc_url($instance[$profile]), $new_window);
            }
        }

        if ($output) {
            $output = str_replace('{WIDGET_INSTANCE_ID}', esc_attr($this->number), $output);
            printf('<ul class="%s">%s</ul>', esc_attr($instance['alignment']), $output);
        }

        echo $after_widget;

        $this->active_instances[] = $this->number;
    }

    function csi_enqueue_css() {

        /**
         * Filter the plugin stylesheet location.
         * @since 1.0
         * @param string $cssfile The full path to the stylesheet.
         */
        $cssfile = apply_filters('csi_custom_social_default_stylesheet', plugin_dir_url(__FILE__) . 'css/style.css');

        wp_enqueue_style('custom-social-media-icons-font', esc_url($cssfile), array(), $this->version, 'all');

        if (!function_exists('is_amp_endpoint') || ( function_exists('is_amp_endpoint') && !is_amp_endpoint() )) {
            wp_enqueue_script('svg-x-use', plugin_dir_url(__FILE__) . 'svgxuse.js', array(), '1.1.21');
        }
    }

    /**
     * Custom CSS.
     * Outputs custom CSS to control the look of the icons.
     */
    function csi_css() {

        #Pull widget settings, merge with defaults
        $all_instances = $this->get_settings();

        $css = '';

        foreach ($this->active_instances as $instance_id) {
            #Skip if info for this instance does not exist - this should never happen.
            if (!isset($all_instances[$instance_id]) || $this->disable_css_output) {
                continue;
            }

            $instance = wp_parse_args($all_instances[$instance_id], $this->defaults);

            $font_size = round((int) $instance['size'] / 2);
            $icon_padding = round((int) $font_size / 2);

            #Treat empty background and border colors as transparent.
            $instance['background_color'] = esc_attr($instance['background_color']) ?: 'transparent';
            $instance['border_color'] = esc_attr($instance['border_color']) ?: 'transparent';
            $instance['background_color_hover'] = esc_attr($instance['background_color_hover']) ?: 'transparent';
            $instance['border_color_hover'] = esc_attr($instance['border_color_hover']) ?: 'transparent';

            #The CSS to output
            $css .= '
			#custom-social-media-icons-' . esc_attr($instance_id) . ' ul li a,
			#custom-social-media-icons-' . esc_attr($instance_id) . ' ul li a:hover,
			#custom-social-media-icons-' . esc_attr($instance_id) . ' ul li a:focus {
				background-color: ' . esc_attr($instance['background_color']) . ' !important;
				border-radius: ' . esc_attr($instance['border_radius']) . 'px;
				color: ' . esc_attr($instance['icon_color']) . ' !important;
				border: ' . esc_attr($instance['border_width']) . 'px ' . esc_attr($instance['border_color']) . ' solid !important;
				font-size: ' . esc_attr($font_size) . 'px;
				padding: ' . esc_attr($icon_padding) . 'px;
			}

			#custom-social-media-icons-' . esc_attr($instance_id) . ' ul li a:hover,
			#custom-social-media-icons-' . esc_attr($instance_id) . ' ul li a:focus {
				background-color: ' . esc_attr($instance['background_color_hover']) . ' !important;
				border-color: ' . esc_attr($instance['border_color_hover']) . ' !important;
				color: ' . esc_attr($instance['icon_color_hover']) . ' !important;
			}

			#custom-social-media-icons-' . esc_attr($instance_id) . ' ul li a:focus {
				outline: 1px dotted ' . esc_attr($instance['background_color_hover']) . ' !important;
			}';
        }

        #Minify a bit.
        $css = str_replace("\t", '', $css);
        $css = str_replace(array("\n", "\r"), ' ', $css);

        echo '<style type="text/css" media="screen">' . esc_attr($css) . '</style>';
    }

    /**
     * Construct the markup for each icon
     * @param string The lowercase icon name for use in tag attributes.
     * @param string The plain text icon label.
     * @return string The full markup for the given icon.
     */
    function csi_get_icon_markup($icon, $label) {
        $markup = '<li class="csi-' . esc_attr($icon) . '"><a href="%s" %s>';
        $markup .= '<svg role="img" class="social-' . esc_attr($icon) . '" aria-labelledby="social-' . esc_attr($icon) . '-{WIDGET_INSTANCE_ID}">';
        $markup .= '<title id="social-' . esc_attr($icon) . '-{WIDGET_INSTANCE_ID}' . '">' . $label . '</title>';
        $markup .= '<use xlink:href="' . esc_attr(plugin_dir_url(__FILE__) . 'symbol-defs.svg#social-' . $icon) . '"></use>';
        $markup .= '</svg></a></li>';

        /**
         * Filter the icon markup HTML.
         * @since 1.0
         * @param string $markup The full HTML markup for a single icon.
         * @param string $icon The lowercase icon name used in tag attributes.
         * @param string $label The plain text icon label.
         */
        return apply_filters('csi_custom_social_icon_html', $markup, $icon, $label);
    }

    /**
     * Remove option when uninstalling the plugin.
     * @since 1.0
     */
    public static function csi_plugin_uninstall() {
        delete_option('widget_custom-social-icons');
    }

}

register_uninstall_hook(__FILE__, array('CSI_Custom_Social_Icons_Widget', 'csi_plugin_uninstall'));
add_action('widgets_init', 'csi_load_widget');

/**
 * Widget Registration.
 * Register Custom Social Media Icons widget.
 */
function csi_load_widget() {
    register_widget('CSI_Custom_Social_Icons_Widget');
}
